@@ -7,6 +7,8 @@ import numpy as np
 import numpy.typing as npt
 import requests
 
+from .margin import HEIGHT_GAP, WIDTH_GAP
+
 HEADERS = {
     "User-Agent": (
         "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_5) "
@@ -25,7 +27,11 @@ class GetJump:
         pass
 
     def get(
-        self, url: str, save_path: str = ".", overwrite: bool = True
+        self,
+        url: str,
+        save_path: str = ".",
+        overwrite: bool = True,
+        only_first: bool = False,
     ) -> tuple[str, str]:
         r = requests.get(url, headers=HEADERS)
         if r.status_code != 200:
@@ -33,8 +39,8 @@ class GetJump:
         j = r.json()["readableProduct"]
         next = j["nextReadableProductUri"]
         next = next + ".json" if type(next) is str else next
-        series_title = j["series"]["title"]
-        title = j["title"]
+        series_title = j["series"]["title"].replace("/", "／")
+        title = j["title"].replace("/", "／")
 
         save_dir = os.path.join(save_path, series_title, title)
         if os.path.exists(save_dir) and not overwrite:
@@ -47,17 +53,21 @@ class GetJump:
         else:
             pages = j["pageStructure"]["pages"]
 
-        self.__save_images(pages, save_dir)
+        self.__save_images(pages, save_dir, only_first)
 
         return next, save_dir
 
-    def __save_images(self, pages: list[Any], save_dir: str) -> None:
+    def __save_images(
+        self, pages: list[Any], save_dir: str, only_first: bool = False
+    ) -> None:
         imgs = []
         for page in pages:
             if "src" not in page:
                 continue
             img = self.__get_image(page)
             imgs.append(img)
+            if only_first:
+                break
 
         len_page_digit = len(str(len(imgs)))
         for idx, img in enumerate(imgs):
@@ -89,12 +99,14 @@ class GetJump:
 
     @staticmethod
     def __get_height_gap(height: int) -> int:
-        if height == 1200:
-            return 16
-        elif height == 1600:
-            return 0
-        elif height == 1024:
-            return 0
+        if height in HEIGHT_GAP:
+            if type(HEIGHT_GAP[height]) is not int:
+                raise ValueError(
+                    "Unresearched height (please let me know with issue <https://git.io/J2jV3>): %d"
+                    % height
+                )
+            else:
+                return HEIGHT_GAP[height]  # type: ignore
         else:
             raise ValueError(
                 "Unfamiliar height (please let me know with issue <https://git.io/J2jV3>): %d"
@@ -103,20 +115,14 @@ class GetJump:
 
     @staticmethod
     def __get_width_gap(width: int) -> int:
-        if width == 760:
-            return 24
-        elif width == 764:
-            return 25
-        elif width == 822:
-            return 22
-        elif width == 1114:
-            return 23
-        elif width == 720:
-            return 15
-        elif width == 704:
-            return 0
-        elif width == 1125:
-            return 2
+        if width in WIDTH_GAP:
+            if type(WIDTH_GAP[width]) is not int:
+                raise ValueError(
+                    "Unresearched width (please let me know with issue <https://git.io/J2jV3>): %d"
+                    % width
+                )
+            else:
+                return WIDTH_GAP[width]  # type: ignore
         else:
             raise ValueError(
                 "Unfamiliar width (please let me know with issue <https://git.io/J2jV3>): %d"
